@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
 
-AGENT_LOG_NAME = 'flylog'
+AGENT_LOGGER_NAME = 'flylog'
 AGENT_HOST = '127.0.0.1'
 AGENT_PORT = 12000
